A guide to understand the processing module
===========================================

The module names indicate the broader function:
* caching: Manages reading from and writing to the SQLite database
* constants: hard-coded definitions
* extracting: Everything related to extracting information from Scopus data
* getting: High-level functions coordinating the retrieval, manipulation and insertion of data
* initializing: Functions just to set up sosia during runtime
* querying: Everything related downloading Scopus data via pybliometrics
* utils: Helper and auxiliary functions
